.. include:: ../src/zope/index/text/README.rst


Reference
=========

Interfaces
----------

.. automodule:: zope.index.text.interfaces

Indexes
-------

.. automodule:: zope.index.text.textindex

.. automodule:: zope.index.text.baseindex

Cosine
~~~~~~

.. autoclass:: zope.index.text.cosineindex.CosineIndex

Okapi
~~~~~

.. automodule:: zope.index.text.okapiindex

Utilities
---------

.. automodule:: zope.index.text.htmlsplitter

.. automodule:: zope.index.text.lexicon

.. automodule:: zope.index.text.setops

.. automodule:: zope.index.text.stopdict

Encodings
~~~~~~~~~
.. automodule:: zope.index.text.ricecode

.. automodule:: zope.index.text.widcode

Query Parser
~~~~~~~~~~~~

.. automodule:: zope.index.text.queryparser
